# -*- coding: utf-8 -*-
# ------------------------------------------------------------------------------
#
#   Copyright 2018-2021 Fetch.AI Limited
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
# ------------------------------------------------------------------------------

# pylint: skip-file

_.Params  # unused method (./auth/interface.py:45)
_.Params  # unused method (./auth/rest_client.py:58)
_.AllBalances  # unused method (./bank/interface.py:55)
_.TotalSupply  # unused method (./bank/interface.py:65)
_.SupplyOf  # unused method (./bank/interface.py:75)
_.Params  # unused method (./bank/interface.py:85)
_.DenomMetadata  # unused method (./bank/interface.py:95)
_.DenomsMetadata  # unused method (./bank/interface.py:107)
_.AllBalances  # unused method (./bank/rest_client.py:70)
_.TotalSupply  # unused method (./bank/rest_client.py:83)
_.SupplyOf  # unused method (./bank/rest_client.py:94)
_.Params  # unused method (./bank/rest_client.py:105)
_.DenomMetadata  # unused method (./bank/rest_client.py:116)
_.DenomsMetadata  # unused method (./bank/rest_client.py:129)
_.get_balance  # unused method (./clients/cosmwasm_client.py:63)
_.query_contract_state  # unused method (./clients/cosmwasm_client.py:98)
_.send_tokens  # unused method (./clients/signing_cosmwasm_client.py:280)
_.deploy_contract  # unused method (./clients/signing_cosmwasm_client.py:297)
_.instantiate_contract  # unused method (./clients/signing_cosmwasm_client.py:319)
_.execute_contract  # unused method (./clients/signing_cosmwasm_client.py:353)
_.public_key_hex  # unused property (./crypto/keypairs.py:64)
_.private_key_hex  # unused property (./crypto/keypairs.py:156)
_.Validators  # unused method (./staking/interface.py:59)
_.Validator  # unused method (./staking/interface.py:63)
_.ValidatorDelegations  # unused method (./staking/interface.py:67)
_.ValidatorUnbondingDelegations  # unused method (./staking/interface.py:73)
_.Delegation  # unused method (./staking/interface.py:79)
_.UnbondingDelegation  # unused method (./staking/interface.py:83)
_.DelegatorDelegations  # unused method (./staking/interface.py:89)
_.DelegatorUnbondingDelegations  # unused method (./staking/interface.py:95)
_.Redelegations  # unused method (./staking/interface.py:101)
_.DelegatorValidators  # unused method (./staking/interface.py:107)
_.DelegatorValidator  # unused method (./staking/interface.py:113)
_.HistoricalInfo  # unused method (./staking/interface.py:119)
_.Pool  # unused method (./staking/interface.py:125)
_.Params  # unused method (./staking/interface.py:129)
StakingRestClient  # unused class (./staking/rest_client.py:58)
_.Validators  # unused method (./staking/rest_client.py:71)
_.Validator  # unused method (./staking/rest_client.py:76)
_.ValidatorDelegations  # unused method (./staking/rest_client.py:83)
_.ValidatorUnbondingDelegations  # unused method (./staking/rest_client.py:94)
_.Delegation  # unused method (./staking/rest_client.py:105)
_.UnbondingDelegation  # unused method (./staking/rest_client.py:112)
_.DelegatorDelegations  # unused method (./staking/rest_client.py:121)
_.DelegatorUnbondingDelegations  # unused method (./staking/rest_client.py:132)
_.Redelegations  # unused method (./staking/rest_client.py:143)
_.DelegatorValidators  # unused method (./staking/rest_client.py:154)
_.DelegatorValidator  # unused method (./staking/rest_client.py:165)
_.HistoricalInfo  # unused method (./staking/rest_client.py:174)
_.Pool  # unused method (./staking/rest_client.py:183)
_.Params  # unused method (./staking/rest_client.py:188)
_.body_bytes  # unused attribute (./tx/__init__.py:46)
_.auth_info_bytes  # unused attribute (./tx/__init__.py:47)

_.Simulate  # unused method (./tx/interface.py:30)
_.GetTxsEvent  # unused method (./tx/interface.py:42)
_.Simulate  # unused method (./tx/rest_client.py:56)
_.GetTxsEvent  # unused method (./tx/rest_client.py:94)

_.get_pubkey_as_str  # unused method (./clients/crypto.py:116)
_.save_key_to_file  # unused method (./clients/crypto.py:132)
_.check_availability  # unused method (./clients/ledger.py:991)
_.validate_address  # unused method (./clients/ledger.py:1018)
_.formatter  # unused attribute (./common/loggers.py:57)
_.handlers  # unused attribute (./common/loggers.py:58)
_.ensure_funds  # unused method (./clients/ledger.py:656)
_.staking_denomination
_.fetch_mainnet
_.is_successful
