# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/channel/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ibc/core/channel/v1/tx.proto',
  package='ibc.core.channel.v1',
  syntax='proto3',
  serialized_options=b'Z9github.com/cosmos/ibc-go/v2/modules/core/04-channel/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1cibc/core/channel/v1/tx.proto\x12\x13ibc.core.channel.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fibc/core/client/v1/client.proto\x1a!ibc/core/channel/v1/channel.proto\"\x88\x01\n\x12MsgChannelOpenInit\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12\x33\n\x07\x63hannel\x18\x02 \x01(\x0b\x32\x1c.ibc.core.channel.v1.ChannelB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x03 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1c\n\x1aMsgChannelOpenInitResponse\"\xfd\x02\n\x11MsgChannelOpenTry\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12;\n\x13previous_channel_id\x18\x02 \x01(\tB\x1e\xf2\xde\x1f\x1ayaml:\"previous_channel_id\"\x12\x33\n\x07\x63hannel\x18\x03 \x01(\x0b\x32\x1c.ibc.core.channel.v1.ChannelB\x04\xc8\xde\x1f\x00\x12=\n\x14\x63ounterparty_version\x18\x04 \x01(\tB\x1f\xf2\xde\x1f\x1byaml:\"counterparty_version\"\x12)\n\nproof_init\x18\x05 \x01(\x0c\x42\x15\xf2\xde\x1f\x11yaml:\"proof_init\"\x12M\n\x0cproof_height\x18\x06 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:\"proof_height\"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x07 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1b\n\x19MsgChannelOpenTryResponse\"\xf9\x02\n\x11MsgChannelOpenAck\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\"\x12\x43\n\x17\x63ounterparty_channel_id\x18\x03 \x01(\tB\"\xf2\xde\x1f\x1eyaml:\"counterparty_channel_id\"\x12=\n\x14\x63ounterparty_version\x18\x04 \x01(\tB\x1f\xf2\xde\x1f\x1byaml:\"counterparty_version\"\x12\'\n\tproof_try\x18\x05 \x01(\x0c\x42\x14\xf2\xde\x1f\x10yaml:\"proof_try\"\x12M\n\x0cproof_height\x18\x06 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:\"proof_height\"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x07 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1b\n\x19MsgChannelOpenAckResponse\"\xf9\x01\n\x15MsgChannelOpenConfirm\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\"\x12\'\n\tproof_ack\x18\x03 \x01(\x0c\x42\x14\xf2\xde\x1f\x10yaml:\"proof_ack\"\x12M\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:\"proof_height\"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1f\n\x1dMsgChannelOpenConfirmResponse\"\x7f\n\x13MsgChannelCloseInit\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\"\x12\x0e\n\x06signer\x18\x03 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1d\n\x1bMsgChannelCloseInitResponse\"\xfc\x01\n\x16MsgChannelCloseConfirm\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\"\x12)\n\nproof_init\x18\x03 \x01(\x0c\x42\x15\xf2\xde\x1f\x11yaml:\"proof_init\"\x12M\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:\"proof_height\"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\" \n\x1eMsgChannelCloseConfirmResponse\"\xe2\x01\n\rMsgRecvPacket\x12\x31\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00\x12\x35\n\x10proof_commitment\x18\x02 \x01(\x0c\x42\x1b\xf2\xde\x1f\x17yaml:\"proof_commitment\"\x12M\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:\"proof_height\"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x04 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x17\n\x15MsgRecvPacketResponse\"\x9a\x02\n\nMsgTimeout\x12\x31\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00\x12\x35\n\x10proof_unreceived\x18\x02 \x01(\x0c\x42\x1b\xf2\xde\x1f\x17yaml:\"proof_unreceived\"\x12M\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:\"proof_height\"\xc8\xde\x1f\x00\x12\x39\n\x12next_sequence_recv\x18\x04 \x01(\x04\x42\x1d\xf2\xde\x1f\x19yaml:\"next_sequence_recv\"\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x14\n\x12MsgTimeoutResponse\"\xce\x02\n\x11MsgTimeoutOnClose\x12\x31\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00\x12\x35\n\x10proof_unreceived\x18\x02 \x01(\x0c\x42\x1b\xf2\xde\x1f\x17yaml:\"proof_unreceived\"\x12+\n\x0bproof_close\x18\x03 \x01(\x0c\x42\x16\xf2\xde\x1f\x12yaml:\"proof_close\"\x12M\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:\"proof_height\"\xc8\xde\x1f\x00\x12\x39\n\x12next_sequence_recv\x18\x05 \x01(\x04\x42\x1d\xf2\xde\x1f\x19yaml:\"next_sequence_recv\"\x12\x0e\n\x06signer\x18\x06 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1b\n\x19MsgTimeoutOnCloseResponse\"\xf6\x01\n\x12MsgAcknowledgement\x12\x31\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00\x12\x17\n\x0f\x61\x63knowledgement\x18\x02 \x01(\x0c\x12+\n\x0bproof_acked\x18\x03 \x01(\x0c\x42\x16\xf2\xde\x1f\x12yaml:\"proof_acked\"\x12M\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:\"proof_height\"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1c\n\x1aMsgAcknowledgementResponse2\xaf\x08\n\x03Msg\x12k\n\x0f\x43hannelOpenInit\x12\'.ibc.core.channel.v1.MsgChannelOpenInit\x1a/.ibc.core.channel.v1.MsgChannelOpenInitResponse\x12h\n\x0e\x43hannelOpenTry\x12&.ibc.core.channel.v1.MsgChannelOpenTry\x1a..ibc.core.channel.v1.MsgChannelOpenTryResponse\x12h\n\x0e\x43hannelOpenAck\x12&.ibc.core.channel.v1.MsgChannelOpenAck\x1a..ibc.core.channel.v1.MsgChannelOpenAckResponse\x12t\n\x12\x43hannelOpenConfirm\x12*.ibc.core.channel.v1.MsgChannelOpenConfirm\x1a\x32.ibc.core.channel.v1.MsgChannelOpenConfirmResponse\x12n\n\x10\x43hannelCloseInit\x12(.ibc.core.channel.v1.MsgChannelCloseInit\x1a\x30.ibc.core.channel.v1.MsgChannelCloseInitResponse\x12w\n\x13\x43hannelCloseConfirm\x12+.ibc.core.channel.v1.MsgChannelCloseConfirm\x1a\x33.ibc.core.channel.v1.MsgChannelCloseConfirmResponse\x12\\\n\nRecvPacket\x12\".ibc.core.channel.v1.MsgRecvPacket\x1a*.ibc.core.channel.v1.MsgRecvPacketResponse\x12S\n\x07Timeout\x12\x1f.ibc.core.channel.v1.MsgTimeout\x1a\'.ibc.core.channel.v1.MsgTimeoutResponse\x12h\n\x0eTimeoutOnClose\x12&.ibc.core.channel.v1.MsgTimeoutOnClose\x1a..ibc.core.channel.v1.MsgTimeoutOnCloseResponse\x12k\n\x0f\x41\x63knowledgement\x12\'.ibc.core.channel.v1.MsgAcknowledgement\x1a/.ibc.core.channel.v1.MsgAcknowledgementResponseB;Z9github.com/cosmos/ibc-go/v2/modules/core/04-channel/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,ibc_dot_core_dot_client_dot_v1_dot_client__pb2.DESCRIPTOR,ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2.DESCRIPTOR,])




_MSGCHANNELOPENINIT = _descriptor.Descriptor(
  name='MsgChannelOpenInit',
  full_name='ibc.core.channel.v1.MsgChannelOpenInit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_id', full_name='ibc.core.channel.v1.MsgChannelOpenInit.port_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\016yaml:\"port_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel', full_name='ibc.core.channel.v1.MsgChannelOpenInit.channel', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signer', full_name='ibc.core.channel.v1.MsgChannelOpenInit.signer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=280,
)


_MSGCHANNELOPENINITRESPONSE = _descriptor.Descriptor(
  name='MsgChannelOpenInitResponse',
  full_name='ibc.core.channel.v1.MsgChannelOpenInitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=282,
  serialized_end=310,
)


_MSGCHANNELOPENTRY = _descriptor.Descriptor(
  name='MsgChannelOpenTry',
  full_name='ibc.core.channel.v1.MsgChannelOpenTry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_id', full_name='ibc.core.channel.v1.MsgChannelOpenTry.port_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\016yaml:\"port_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previous_channel_id', full_name='ibc.core.channel.v1.MsgChannelOpenTry.previous_channel_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\032yaml:\"previous_channel_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel', full_name='ibc.core.channel.v1.MsgChannelOpenTry.channel', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counterparty_version', full_name='ibc.core.channel.v1.MsgChannelOpenTry.counterparty_version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\033yaml:\"counterparty_version\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_init', full_name='ibc.core.channel.v1.MsgChannelOpenTry.proof_init', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\021yaml:\"proof_init\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_height', full_name='ibc.core.channel.v1.MsgChannelOpenTry.proof_height', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"proof_height\"\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signer', full_name='ibc.core.channel.v1.MsgChannelOpenTry.signer', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=694,
)


_MSGCHANNELOPENTRYRESPONSE = _descriptor.Descriptor(
  name='MsgChannelOpenTryResponse',
  full_name='ibc.core.channel.v1.MsgChannelOpenTryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=696,
  serialized_end=723,
)


_MSGCHANNELOPENACK = _descriptor.Descriptor(
  name='MsgChannelOpenAck',
  full_name='ibc.core.channel.v1.MsgChannelOpenAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_id', full_name='ibc.core.channel.v1.MsgChannelOpenAck.port_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\016yaml:\"port_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='ibc.core.channel.v1.MsgChannelOpenAck.channel_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\021yaml:\"channel_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counterparty_channel_id', full_name='ibc.core.channel.v1.MsgChannelOpenAck.counterparty_channel_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\036yaml:\"counterparty_channel_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counterparty_version', full_name='ibc.core.channel.v1.MsgChannelOpenAck.counterparty_version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\033yaml:\"counterparty_version\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_try', full_name='ibc.core.channel.v1.MsgChannelOpenAck.proof_try', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\020yaml:\"proof_try\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_height', full_name='ibc.core.channel.v1.MsgChannelOpenAck.proof_height', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"proof_height\"\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signer', full_name='ibc.core.channel.v1.MsgChannelOpenAck.signer', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=726,
  serialized_end=1103,
)


_MSGCHANNELOPENACKRESPONSE = _descriptor.Descriptor(
  name='MsgChannelOpenAckResponse',
  full_name='ibc.core.channel.v1.MsgChannelOpenAckResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1105,
  serialized_end=1132,
)


_MSGCHANNELOPENCONFIRM = _descriptor.Descriptor(
  name='MsgChannelOpenConfirm',
  full_name='ibc.core.channel.v1.MsgChannelOpenConfirm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_id', full_name='ibc.core.channel.v1.MsgChannelOpenConfirm.port_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\016yaml:\"port_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='ibc.core.channel.v1.MsgChannelOpenConfirm.channel_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\021yaml:\"channel_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_ack', full_name='ibc.core.channel.v1.MsgChannelOpenConfirm.proof_ack', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\020yaml:\"proof_ack\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_height', full_name='ibc.core.channel.v1.MsgChannelOpenConfirm.proof_height', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"proof_height\"\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signer', full_name='ibc.core.channel.v1.MsgChannelOpenConfirm.signer', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1135,
  serialized_end=1384,
)


_MSGCHANNELOPENCONFIRMRESPONSE = _descriptor.Descriptor(
  name='MsgChannelOpenConfirmResponse',
  full_name='ibc.core.channel.v1.MsgChannelOpenConfirmResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1386,
  serialized_end=1417,
)


_MSGCHANNELCLOSEINIT = _descriptor.Descriptor(
  name='MsgChannelCloseInit',
  full_name='ibc.core.channel.v1.MsgChannelCloseInit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_id', full_name='ibc.core.channel.v1.MsgChannelCloseInit.port_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\016yaml:\"port_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='ibc.core.channel.v1.MsgChannelCloseInit.channel_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\021yaml:\"channel_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signer', full_name='ibc.core.channel.v1.MsgChannelCloseInit.signer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1419,
  serialized_end=1546,
)


_MSGCHANNELCLOSEINITRESPONSE = _descriptor.Descriptor(
  name='MsgChannelCloseInitResponse',
  full_name='ibc.core.channel.v1.MsgChannelCloseInitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1548,
  serialized_end=1577,
)


_MSGCHANNELCLOSECONFIRM = _descriptor.Descriptor(
  name='MsgChannelCloseConfirm',
  full_name='ibc.core.channel.v1.MsgChannelCloseConfirm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_id', full_name='ibc.core.channel.v1.MsgChannelCloseConfirm.port_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\016yaml:\"port_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='ibc.core.channel.v1.MsgChannelCloseConfirm.channel_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\021yaml:\"channel_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_init', full_name='ibc.core.channel.v1.MsgChannelCloseConfirm.proof_init', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\021yaml:\"proof_init\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_height', full_name='ibc.core.channel.v1.MsgChannelCloseConfirm.proof_height', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"proof_height\"\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signer', full_name='ibc.core.channel.v1.MsgChannelCloseConfirm.signer', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1580,
  serialized_end=1832,
)


_MSGCHANNELCLOSECONFIRMRESPONSE = _descriptor.Descriptor(
  name='MsgChannelCloseConfirmResponse',
  full_name='ibc.core.channel.v1.MsgChannelCloseConfirmResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1834,
  serialized_end=1866,
)


_MSGRECVPACKET = _descriptor.Descriptor(
  name='MsgRecvPacket',
  full_name='ibc.core.channel.v1.MsgRecvPacket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='packet', full_name='ibc.core.channel.v1.MsgRecvPacket.packet', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_commitment', full_name='ibc.core.channel.v1.MsgRecvPacket.proof_commitment', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\027yaml:\"proof_commitment\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_height', full_name='ibc.core.channel.v1.MsgRecvPacket.proof_height', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"proof_height\"\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signer', full_name='ibc.core.channel.v1.MsgRecvPacket.signer', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1869,
  serialized_end=2095,
)


_MSGRECVPACKETRESPONSE = _descriptor.Descriptor(
  name='MsgRecvPacketResponse',
  full_name='ibc.core.channel.v1.MsgRecvPacketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2097,
  serialized_end=2120,
)


_MSGTIMEOUT = _descriptor.Descriptor(
  name='MsgTimeout',
  full_name='ibc.core.channel.v1.MsgTimeout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='packet', full_name='ibc.core.channel.v1.MsgTimeout.packet', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_unreceived', full_name='ibc.core.channel.v1.MsgTimeout.proof_unreceived', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\027yaml:\"proof_unreceived\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_height', full_name='ibc.core.channel.v1.MsgTimeout.proof_height', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"proof_height\"\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_sequence_recv', full_name='ibc.core.channel.v1.MsgTimeout.next_sequence_recv', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\031yaml:\"next_sequence_recv\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signer', full_name='ibc.core.channel.v1.MsgTimeout.signer', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2123,
  serialized_end=2405,
)


_MSGTIMEOUTRESPONSE = _descriptor.Descriptor(
  name='MsgTimeoutResponse',
  full_name='ibc.core.channel.v1.MsgTimeoutResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2407,
  serialized_end=2427,
)


_MSGTIMEOUTONCLOSE = _descriptor.Descriptor(
  name='MsgTimeoutOnClose',
  full_name='ibc.core.channel.v1.MsgTimeoutOnClose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='packet', full_name='ibc.core.channel.v1.MsgTimeoutOnClose.packet', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_unreceived', full_name='ibc.core.channel.v1.MsgTimeoutOnClose.proof_unreceived', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\027yaml:\"proof_unreceived\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_close', full_name='ibc.core.channel.v1.MsgTimeoutOnClose.proof_close', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\022yaml:\"proof_close\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_height', full_name='ibc.core.channel.v1.MsgTimeoutOnClose.proof_height', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"proof_height\"\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_sequence_recv', full_name='ibc.core.channel.v1.MsgTimeoutOnClose.next_sequence_recv', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\031yaml:\"next_sequence_recv\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signer', full_name='ibc.core.channel.v1.MsgTimeoutOnClose.signer', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2430,
  serialized_end=2764,
)


_MSGTIMEOUTONCLOSERESPONSE = _descriptor.Descriptor(
  name='MsgTimeoutOnCloseResponse',
  full_name='ibc.core.channel.v1.MsgTimeoutOnCloseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2766,
  serialized_end=2793,
)


_MSGACKNOWLEDGEMENT = _descriptor.Descriptor(
  name='MsgAcknowledgement',
  full_name='ibc.core.channel.v1.MsgAcknowledgement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='packet', full_name='ibc.core.channel.v1.MsgAcknowledgement.packet', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acknowledgement', full_name='ibc.core.channel.v1.MsgAcknowledgement.acknowledgement', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_acked', full_name='ibc.core.channel.v1.MsgAcknowledgement.proof_acked', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\022yaml:\"proof_acked\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof_height', full_name='ibc.core.channel.v1.MsgAcknowledgement.proof_height', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"proof_height\"\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signer', full_name='ibc.core.channel.v1.MsgAcknowledgement.signer', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2796,
  serialized_end=3042,
)


_MSGACKNOWLEDGEMENTRESPONSE = _descriptor.Descriptor(
  name='MsgAcknowledgementResponse',
  full_name='ibc.core.channel.v1.MsgAcknowledgementResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3044,
  serialized_end=3072,
)

_MSGCHANNELOPENINIT.fields_by_name['channel'].message_type = ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2._CHANNEL
_MSGCHANNELOPENTRY.fields_by_name['channel'].message_type = ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2._CHANNEL
_MSGCHANNELOPENTRY.fields_by_name['proof_height'].message_type = ibc_dot_core_dot_client_dot_v1_dot_client__pb2._HEIGHT
_MSGCHANNELOPENACK.fields_by_name['proof_height'].message_type = ibc_dot_core_dot_client_dot_v1_dot_client__pb2._HEIGHT
_MSGCHANNELOPENCONFIRM.fields_by_name['proof_height'].message_type = ibc_dot_core_dot_client_dot_v1_dot_client__pb2._HEIGHT
_MSGCHANNELCLOSECONFIRM.fields_by_name['proof_height'].message_type = ibc_dot_core_dot_client_dot_v1_dot_client__pb2._HEIGHT
_MSGRECVPACKET.fields_by_name['packet'].message_type = ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2._PACKET
_MSGRECVPACKET.fields_by_name['proof_height'].message_type = ibc_dot_core_dot_client_dot_v1_dot_client__pb2._HEIGHT
_MSGTIMEOUT.fields_by_name['packet'].message_type = ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2._PACKET
_MSGTIMEOUT.fields_by_name['proof_height'].message_type = ibc_dot_core_dot_client_dot_v1_dot_client__pb2._HEIGHT
_MSGTIMEOUTONCLOSE.fields_by_name['packet'].message_type = ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2._PACKET
_MSGTIMEOUTONCLOSE.fields_by_name['proof_height'].message_type = ibc_dot_core_dot_client_dot_v1_dot_client__pb2._HEIGHT
_MSGACKNOWLEDGEMENT.fields_by_name['packet'].message_type = ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2._PACKET
_MSGACKNOWLEDGEMENT.fields_by_name['proof_height'].message_type = ibc_dot_core_dot_client_dot_v1_dot_client__pb2._HEIGHT
DESCRIPTOR.message_types_by_name['MsgChannelOpenInit'] = _MSGCHANNELOPENINIT
DESCRIPTOR.message_types_by_name['MsgChannelOpenInitResponse'] = _MSGCHANNELOPENINITRESPONSE
DESCRIPTOR.message_types_by_name['MsgChannelOpenTry'] = _MSGCHANNELOPENTRY
DESCRIPTOR.message_types_by_name['MsgChannelOpenTryResponse'] = _MSGCHANNELOPENTRYRESPONSE
DESCRIPTOR.message_types_by_name['MsgChannelOpenAck'] = _MSGCHANNELOPENACK
DESCRIPTOR.message_types_by_name['MsgChannelOpenAckResponse'] = _MSGCHANNELOPENACKRESPONSE
DESCRIPTOR.message_types_by_name['MsgChannelOpenConfirm'] = _MSGCHANNELOPENCONFIRM
DESCRIPTOR.message_types_by_name['MsgChannelOpenConfirmResponse'] = _MSGCHANNELOPENCONFIRMRESPONSE
DESCRIPTOR.message_types_by_name['MsgChannelCloseInit'] = _MSGCHANNELCLOSEINIT
DESCRIPTOR.message_types_by_name['MsgChannelCloseInitResponse'] = _MSGCHANNELCLOSEINITRESPONSE
DESCRIPTOR.message_types_by_name['MsgChannelCloseConfirm'] = _MSGCHANNELCLOSECONFIRM
DESCRIPTOR.message_types_by_name['MsgChannelCloseConfirmResponse'] = _MSGCHANNELCLOSECONFIRMRESPONSE
DESCRIPTOR.message_types_by_name['MsgRecvPacket'] = _MSGRECVPACKET
DESCRIPTOR.message_types_by_name['MsgRecvPacketResponse'] = _MSGRECVPACKETRESPONSE
DESCRIPTOR.message_types_by_name['MsgTimeout'] = _MSGTIMEOUT
DESCRIPTOR.message_types_by_name['MsgTimeoutResponse'] = _MSGTIMEOUTRESPONSE
DESCRIPTOR.message_types_by_name['MsgTimeoutOnClose'] = _MSGTIMEOUTONCLOSE
DESCRIPTOR.message_types_by_name['MsgTimeoutOnCloseResponse'] = _MSGTIMEOUTONCLOSERESPONSE
DESCRIPTOR.message_types_by_name['MsgAcknowledgement'] = _MSGACKNOWLEDGEMENT
DESCRIPTOR.message_types_by_name['MsgAcknowledgementResponse'] = _MSGACKNOWLEDGEMENTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsgChannelOpenInit = _reflection.GeneratedProtocolMessageType('MsgChannelOpenInit', (_message.Message,), {
  'DESCRIPTOR' : _MSGCHANNELOPENINIT,
  '__module__' : 'ibc.core.channel.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.MsgChannelOpenInit)
  })
_sym_db.RegisterMessage(MsgChannelOpenInit)

MsgChannelOpenInitResponse = _reflection.GeneratedProtocolMessageType('MsgChannelOpenInitResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCHANNELOPENINITRESPONSE,
  '__module__' : 'ibc.core.channel.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.MsgChannelOpenInitResponse)
  })
_sym_db.RegisterMessage(MsgChannelOpenInitResponse)

MsgChannelOpenTry = _reflection.GeneratedProtocolMessageType('MsgChannelOpenTry', (_message.Message,), {
  'DESCRIPTOR' : _MSGCHANNELOPENTRY,
  '__module__' : 'ibc.core.channel.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.MsgChannelOpenTry)
  })
_sym_db.RegisterMessage(MsgChannelOpenTry)

MsgChannelOpenTryResponse = _reflection.GeneratedProtocolMessageType('MsgChannelOpenTryResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCHANNELOPENTRYRESPONSE,
  '__module__' : 'ibc.core.channel.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.MsgChannelOpenTryResponse)
  })
_sym_db.RegisterMessage(MsgChannelOpenTryResponse)

MsgChannelOpenAck = _reflection.GeneratedProtocolMessageType('MsgChannelOpenAck', (_message.Message,), {
  'DESCRIPTOR' : _MSGCHANNELOPENACK,
  '__module__' : 'ibc.core.channel.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.MsgChannelOpenAck)
  })
_sym_db.RegisterMessage(MsgChannelOpenAck)

MsgChannelOpenAckResponse = _reflection.GeneratedProtocolMessageType('MsgChannelOpenAckResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCHANNELOPENACKRESPONSE,
  '__module__' : 'ibc.core.channel.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.MsgChannelOpenAckResponse)
  })
_sym_db.RegisterMessage(MsgChannelOpenAckResponse)

MsgChannelOpenConfirm = _reflection.GeneratedProtocolMessageType('MsgChannelOpenConfirm', (_message.Message,), {
  'DESCRIPTOR' : _MSGCHANNELOPENCONFIRM,
  '__module__' : 'ibc.core.channel.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.MsgChannelOpenConfirm)
  })
_sym_db.RegisterMessage(MsgChannelOpenConfirm)

MsgChannelOpenConfirmResponse = _reflection.GeneratedProtocolMessageType('MsgChannelOpenConfirmResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCHANNELOPENCONFIRMRESPONSE,
  '__module__' : 'ibc.core.channel.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.MsgChannelOpenConfirmResponse)
  })
_sym_db.RegisterMessage(MsgChannelOpenConfirmResponse)

MsgChannelCloseInit = _reflection.GeneratedProtocolMessageType('MsgChannelCloseInit', (_message.Message,), {
  'DESCRIPTOR' : _MSGCHANNELCLOSEINIT,
  '__module__' : 'ibc.core.channel.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.MsgChannelCloseInit)
  })
_sym_db.RegisterMessage(MsgChannelCloseInit)

MsgChannelCloseInitResponse = _reflection.GeneratedProtocolMessageType('MsgChannelCloseInitResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCHANNELCLOSEINITRESPONSE,
  '__module__' : 'ibc.core.channel.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.MsgChannelCloseInitResponse)
  })
_sym_db.RegisterMessage(MsgChannelCloseInitResponse)

MsgChannelCloseConfirm = _reflection.GeneratedProtocolMessageType('MsgChannelCloseConfirm', (_message.Message,), {
  'DESCRIPTOR' : _MSGCHANNELCLOSECONFIRM,
  '__module__' : 'ibc.core.channel.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.MsgChannelCloseConfirm)
  })
_sym_db.RegisterMessage(MsgChannelCloseConfirm)

MsgChannelCloseConfirmResponse = _reflection.GeneratedProtocolMessageType('MsgChannelCloseConfirmResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCHANNELCLOSECONFIRMRESPONSE,
  '__module__' : 'ibc.core.channel.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.MsgChannelCloseConfirmResponse)
  })
_sym_db.RegisterMessage(MsgChannelCloseConfirmResponse)

MsgRecvPacket = _reflection.GeneratedProtocolMessageType('MsgRecvPacket', (_message.Message,), {
  'DESCRIPTOR' : _MSGRECVPACKET,
  '__module__' : 'ibc.core.channel.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.MsgRecvPacket)
  })
_sym_db.RegisterMessage(MsgRecvPacket)

MsgRecvPacketResponse = _reflection.GeneratedProtocolMessageType('MsgRecvPacketResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGRECVPACKETRESPONSE,
  '__module__' : 'ibc.core.channel.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.MsgRecvPacketResponse)
  })
_sym_db.RegisterMessage(MsgRecvPacketResponse)

MsgTimeout = _reflection.GeneratedProtocolMessageType('MsgTimeout', (_message.Message,), {
  'DESCRIPTOR' : _MSGTIMEOUT,
  '__module__' : 'ibc.core.channel.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.MsgTimeout)
  })
_sym_db.RegisterMessage(MsgTimeout)

MsgTimeoutResponse = _reflection.GeneratedProtocolMessageType('MsgTimeoutResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGTIMEOUTRESPONSE,
  '__module__' : 'ibc.core.channel.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.MsgTimeoutResponse)
  })
_sym_db.RegisterMessage(MsgTimeoutResponse)

MsgTimeoutOnClose = _reflection.GeneratedProtocolMessageType('MsgTimeoutOnClose', (_message.Message,), {
  'DESCRIPTOR' : _MSGTIMEOUTONCLOSE,
  '__module__' : 'ibc.core.channel.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.MsgTimeoutOnClose)
  })
_sym_db.RegisterMessage(MsgTimeoutOnClose)

MsgTimeoutOnCloseResponse = _reflection.GeneratedProtocolMessageType('MsgTimeoutOnCloseResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGTIMEOUTONCLOSERESPONSE,
  '__module__' : 'ibc.core.channel.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.MsgTimeoutOnCloseResponse)
  })
_sym_db.RegisterMessage(MsgTimeoutOnCloseResponse)

MsgAcknowledgement = _reflection.GeneratedProtocolMessageType('MsgAcknowledgement', (_message.Message,), {
  'DESCRIPTOR' : _MSGACKNOWLEDGEMENT,
  '__module__' : 'ibc.core.channel.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.MsgAcknowledgement)
  })
_sym_db.RegisterMessage(MsgAcknowledgement)

MsgAcknowledgementResponse = _reflection.GeneratedProtocolMessageType('MsgAcknowledgementResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGACKNOWLEDGEMENTRESPONSE,
  '__module__' : 'ibc.core.channel.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.MsgAcknowledgementResponse)
  })
_sym_db.RegisterMessage(MsgAcknowledgementResponse)


DESCRIPTOR._options = None
_MSGCHANNELOPENINIT.fields_by_name['port_id']._options = None
_MSGCHANNELOPENINIT.fields_by_name['channel']._options = None
_MSGCHANNELOPENINIT._options = None
_MSGCHANNELOPENTRY.fields_by_name['port_id']._options = None
_MSGCHANNELOPENTRY.fields_by_name['previous_channel_id']._options = None
_MSGCHANNELOPENTRY.fields_by_name['channel']._options = None
_MSGCHANNELOPENTRY.fields_by_name['counterparty_version']._options = None
_MSGCHANNELOPENTRY.fields_by_name['proof_init']._options = None
_MSGCHANNELOPENTRY.fields_by_name['proof_height']._options = None
_MSGCHANNELOPENTRY._options = None
_MSGCHANNELOPENACK.fields_by_name['port_id']._options = None
_MSGCHANNELOPENACK.fields_by_name['channel_id']._options = None
_MSGCHANNELOPENACK.fields_by_name['counterparty_channel_id']._options = None
_MSGCHANNELOPENACK.fields_by_name['counterparty_version']._options = None
_MSGCHANNELOPENACK.fields_by_name['proof_try']._options = None
_MSGCHANNELOPENACK.fields_by_name['proof_height']._options = None
_MSGCHANNELOPENACK._options = None
_MSGCHANNELOPENCONFIRM.fields_by_name['port_id']._options = None
_MSGCHANNELOPENCONFIRM.fields_by_name['channel_id']._options = None
_MSGCHANNELOPENCONFIRM.fields_by_name['proof_ack']._options = None
_MSGCHANNELOPENCONFIRM.fields_by_name['proof_height']._options = None
_MSGCHANNELOPENCONFIRM._options = None
_MSGCHANNELCLOSEINIT.fields_by_name['port_id']._options = None
_MSGCHANNELCLOSEINIT.fields_by_name['channel_id']._options = None
_MSGCHANNELCLOSEINIT._options = None
_MSGCHANNELCLOSECONFIRM.fields_by_name['port_id']._options = None
_MSGCHANNELCLOSECONFIRM.fields_by_name['channel_id']._options = None
_MSGCHANNELCLOSECONFIRM.fields_by_name['proof_init']._options = None
_MSGCHANNELCLOSECONFIRM.fields_by_name['proof_height']._options = None
_MSGCHANNELCLOSECONFIRM._options = None
_MSGRECVPACKET.fields_by_name['packet']._options = None
_MSGRECVPACKET.fields_by_name['proof_commitment']._options = None
_MSGRECVPACKET.fields_by_name['proof_height']._options = None
_MSGRECVPACKET._options = None
_MSGTIMEOUT.fields_by_name['packet']._options = None
_MSGTIMEOUT.fields_by_name['proof_unreceived']._options = None
_MSGTIMEOUT.fields_by_name['proof_height']._options = None
_MSGTIMEOUT.fields_by_name['next_sequence_recv']._options = None
_MSGTIMEOUT._options = None
_MSGTIMEOUTONCLOSE.fields_by_name['packet']._options = None
_MSGTIMEOUTONCLOSE.fields_by_name['proof_unreceived']._options = None
_MSGTIMEOUTONCLOSE.fields_by_name['proof_close']._options = None
_MSGTIMEOUTONCLOSE.fields_by_name['proof_height']._options = None
_MSGTIMEOUTONCLOSE.fields_by_name['next_sequence_recv']._options = None
_MSGTIMEOUTONCLOSE._options = None
_MSGACKNOWLEDGEMENT.fields_by_name['packet']._options = None
_MSGACKNOWLEDGEMENT.fields_by_name['proof_acked']._options = None
_MSGACKNOWLEDGEMENT.fields_by_name['proof_height']._options = None
_MSGACKNOWLEDGEMENT._options = None

_MSG = _descriptor.ServiceDescriptor(
  name='Msg',
  full_name='ibc.core.channel.v1.Msg',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3075,
  serialized_end=4146,
  methods=[
  _descriptor.MethodDescriptor(
    name='ChannelOpenInit',
    full_name='ibc.core.channel.v1.Msg.ChannelOpenInit',
    index=0,
    containing_service=None,
    input_type=_MSGCHANNELOPENINIT,
    output_type=_MSGCHANNELOPENINITRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChannelOpenTry',
    full_name='ibc.core.channel.v1.Msg.ChannelOpenTry',
    index=1,
    containing_service=None,
    input_type=_MSGCHANNELOPENTRY,
    output_type=_MSGCHANNELOPENTRYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChannelOpenAck',
    full_name='ibc.core.channel.v1.Msg.ChannelOpenAck',
    index=2,
    containing_service=None,
    input_type=_MSGCHANNELOPENACK,
    output_type=_MSGCHANNELOPENACKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChannelOpenConfirm',
    full_name='ibc.core.channel.v1.Msg.ChannelOpenConfirm',
    index=3,
    containing_service=None,
    input_type=_MSGCHANNELOPENCONFIRM,
    output_type=_MSGCHANNELOPENCONFIRMRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChannelCloseInit',
    full_name='ibc.core.channel.v1.Msg.ChannelCloseInit',
    index=4,
    containing_service=None,
    input_type=_MSGCHANNELCLOSEINIT,
    output_type=_MSGCHANNELCLOSEINITRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChannelCloseConfirm',
    full_name='ibc.core.channel.v1.Msg.ChannelCloseConfirm',
    index=5,
    containing_service=None,
    input_type=_MSGCHANNELCLOSECONFIRM,
    output_type=_MSGCHANNELCLOSECONFIRMRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RecvPacket',
    full_name='ibc.core.channel.v1.Msg.RecvPacket',
    index=6,
    containing_service=None,
    input_type=_MSGRECVPACKET,
    output_type=_MSGRECVPACKETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Timeout',
    full_name='ibc.core.channel.v1.Msg.Timeout',
    index=7,
    containing_service=None,
    input_type=_MSGTIMEOUT,
    output_type=_MSGTIMEOUTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TimeoutOnClose',
    full_name='ibc.core.channel.v1.Msg.TimeoutOnClose',
    index=8,
    containing_service=None,
    input_type=_MSGTIMEOUTONCLOSE,
    output_type=_MSGTIMEOUTONCLOSERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Acknowledgement',
    full_name='ibc.core.channel.v1.Msg.Acknowledgement',
    index=9,
    containing_service=None,
    input_type=_MSGACKNOWLEDGEMENT,
    output_type=_MSGACKNOWLEDGEMENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MSG)

DESCRIPTOR.services_by_name['Msg'] = _MSG

# @@protoc_insertion_point(module_scope)
