# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/transfer/v2/packet.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ibc/applications/transfer/v2/packet.proto',
  package='ibc.applications.transfer.v2',
  syntax='proto3',
  serialized_options=b'Z7github.com/cosmos/ibc-go/v2/modules/apps/transfer/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)ibc/applications/transfer/v2/packet.proto\x12\x1cibc.applications.transfer.v2\"Z\n\x17\x46ungibleTokenPacketData\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\x12\x0e\n\x06sender\x18\x03 \x01(\t\x12\x10\n\x08receiver\x18\x04 \x01(\tB9Z7github.com/cosmos/ibc-go/v2/modules/apps/transfer/typesb\x06proto3'
)




_FUNGIBLETOKENPACKETDATA = _descriptor.Descriptor(
  name='FungibleTokenPacketData',
  full_name='ibc.applications.transfer.v2.FungibleTokenPacketData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='denom', full_name='ibc.applications.transfer.v2.FungibleTokenPacketData.denom', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='ibc.applications.transfer.v2.FungibleTokenPacketData.amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender', full_name='ibc.applications.transfer.v2.FungibleTokenPacketData.sender', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receiver', full_name='ibc.applications.transfer.v2.FungibleTokenPacketData.receiver', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=165,
)

DESCRIPTOR.message_types_by_name['FungibleTokenPacketData'] = _FUNGIBLETOKENPACKETDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FungibleTokenPacketData = _reflection.GeneratedProtocolMessageType('FungibleTokenPacketData', (_message.Message,), {
  'DESCRIPTOR' : _FUNGIBLETOKENPACKETDATA,
  '__module__' : 'ibc.applications.transfer.v2.packet_pb2'
  # @@protoc_insertion_point(class_scope:ibc.applications.transfer.v2.FungibleTokenPacketData)
  })
_sym_db.RegisterMessage(FungibleTokenPacketData)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
