# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/reflection/v2alpha1/reflection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/base/reflection/v2alpha1/reflection.proto',
  package='cosmos.base.reflection.v2alpha1',
  syntax='proto3',
  serialized_options=b'Z<github.com/cosmos/cosmos-sdk/server/grpc/reflection/v2alpha1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0cosmos/base/reflection/v2alpha1/reflection.proto\x12\x1f\x63osmos.base.reflection.v2alpha1\x1a\x1cgoogle/api/annotations.proto\"\xb0\x03\n\rAppDescriptor\x12?\n\x05\x61uthn\x18\x01 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.AuthnDescriptor\x12?\n\x05\x63hain\x18\x02 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.ChainDescriptor\x12?\n\x05\x63odec\x18\x03 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.CodecDescriptor\x12O\n\rconfiguration\x18\x04 \x01(\x0b\x32\x38.cosmos.base.reflection.v2alpha1.ConfigurationDescriptor\x12P\n\x0equery_services\x18\x05 \x01(\x0b\x32\x38.cosmos.base.reflection.v2alpha1.QueryServicesDescriptor\x12\x39\n\x02tx\x18\x06 \x01(\x0b\x32-.cosmos.base.reflection.v2alpha1.TxDescriptor\"^\n\x0cTxDescriptor\x12\x10\n\x08\x66ullname\x18\x01 \x01(\t\x12<\n\x04msgs\x18\x02 \x03(\x0b\x32..cosmos.base.reflection.v2alpha1.MsgDescriptor\"]\n\x0f\x41uthnDescriptor\x12J\n\nsign_modes\x18\x01 \x03(\x0b\x32\x36.cosmos.base.reflection.v2alpha1.SigningModeDescriptor\"b\n\x15SigningModeDescriptor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\x05\x12+\n#authn_info_provider_method_fullname\x18\x03 \x01(\t\"\x1d\n\x0f\x43hainDescriptor\x12\n\n\x02id\x18\x01 \x01(\t\"[\n\x0f\x43odecDescriptor\x12H\n\ninterfaces\x18\x01 \x03(\x0b\x32\x34.cosmos.base.reflection.v2alpha1.InterfaceDescriptor\"\xf4\x01\n\x13InterfaceDescriptor\x12\x10\n\x08\x66ullname\x18\x01 \x01(\t\x12j\n\x1cinterface_accepting_messages\x18\x02 \x03(\x0b\x32\x44.cosmos.base.reflection.v2alpha1.InterfaceAcceptingMessageDescriptor\x12_\n\x16interface_implementers\x18\x03 \x03(\x0b\x32?.cosmos.base.reflection.v2alpha1.InterfaceImplementerDescriptor\"D\n\x1eInterfaceImplementerDescriptor\x12\x10\n\x08\x66ullname\x18\x01 \x01(\t\x12\x10\n\x08type_url\x18\x02 \x01(\t\"W\n#InterfaceAcceptingMessageDescriptor\x12\x10\n\x08\x66ullname\x18\x01 \x01(\t\x12\x1e\n\x16\x66ield_descriptor_names\x18\x02 \x03(\t\"@\n\x17\x43onfigurationDescriptor\x12%\n\x1d\x62\x65\x63h32_account_address_prefix\x18\x01 \x01(\t\"%\n\rMsgDescriptor\x12\x14\n\x0cmsg_type_url\x18\x01 \x01(\t\"\x1b\n\x19GetAuthnDescriptorRequest\"]\n\x1aGetAuthnDescriptorResponse\x12?\n\x05\x61uthn\x18\x01 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.AuthnDescriptor\"\x1b\n\x19GetChainDescriptorRequest\"]\n\x1aGetChainDescriptorResponse\x12?\n\x05\x63hain\x18\x01 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.ChainDescriptor\"\x1b\n\x19GetCodecDescriptorRequest\"]\n\x1aGetCodecDescriptorResponse\x12?\n\x05\x63odec\x18\x01 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.CodecDescriptor\"#\n!GetConfigurationDescriptorRequest\"n\n\"GetConfigurationDescriptorResponse\x12H\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x38.cosmos.base.reflection.v2alpha1.ConfigurationDescriptor\"#\n!GetQueryServicesDescriptorRequest\"o\n\"GetQueryServicesDescriptorResponse\x12I\n\x07queries\x18\x01 \x01(\x0b\x32\x38.cosmos.base.reflection.v2alpha1.QueryServicesDescriptor\"\x18\n\x16GetTxDescriptorRequest\"T\n\x17GetTxDescriptorResponse\x12\x39\n\x02tx\x18\x01 \x01(\x0b\x32-.cosmos.base.reflection.v2alpha1.TxDescriptor\"j\n\x17QueryServicesDescriptor\x12O\n\x0equery_services\x18\x01 \x03(\x0b\x32\x37.cosmos.base.reflection.v2alpha1.QueryServiceDescriptor\"\x86\x01\n\x16QueryServiceDescriptor\x12\x10\n\x08\x66ullname\x18\x01 \x01(\t\x12\x11\n\tis_module\x18\x02 \x01(\x08\x12G\n\x07methods\x18\x03 \x03(\x0b\x32\x36.cosmos.base.reflection.v2alpha1.QueryMethodDescriptor\">\n\x15QueryMethodDescriptor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0f\x66ull_query_path\x18\x02 \x01(\t2\xa7\n\n\x11ReflectionService\x12\xcb\x01\n\x12GetAuthnDescriptor\x12:.cosmos.base.reflection.v2alpha1.GetAuthnDescriptorRequest\x1a;.cosmos.base.reflection.v2alpha1.GetAuthnDescriptorResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/base/reflection/v1beta1/app_descriptor/authn\x12\xcb\x01\n\x12GetChainDescriptor\x12:.cosmos.base.reflection.v2alpha1.GetChainDescriptorRequest\x1a;.cosmos.base.reflection.v2alpha1.GetChainDescriptorResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/base/reflection/v1beta1/app_descriptor/chain\x12\xcb\x01\n\x12GetCodecDescriptor\x12:.cosmos.base.reflection.v2alpha1.GetCodecDescriptorRequest\x1a;.cosmos.base.reflection.v2alpha1.GetCodecDescriptorResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/base/reflection/v1beta1/app_descriptor/codec\x12\xeb\x01\n\x1aGetConfigurationDescriptor\x12\x42.cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorRequest\x1a\x43.cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorResponse\"D\x82\xd3\xe4\x93\x02>\x12</cosmos/base/reflection/v1beta1/app_descriptor/configuration\x12\xec\x01\n\x1aGetQueryServicesDescriptor\x12\x42.cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorRequest\x1a\x43.cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorResponse\"E\x82\xd3\xe4\x93\x02?\x12=/cosmos/base/reflection/v1beta1/app_descriptor/query_services\x12\xca\x01\n\x0fGetTxDescriptor\x12\x37.cosmos.base.reflection.v2alpha1.GetTxDescriptorRequest\x1a\x38.cosmos.base.reflection.v2alpha1.GetTxDescriptorResponse\"D\x82\xd3\xe4\x93\x02>\x12</cosmos/base/reflection/v1beta1/app_descriptor/tx_descriptorB>Z<github.com/cosmos/cosmos-sdk/server/grpc/reflection/v2alpha1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_APPDESCRIPTOR = _descriptor.Descriptor(
  name='AppDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.AppDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='authn', full_name='cosmos.base.reflection.v2alpha1.AppDescriptor.authn', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain', full_name='cosmos.base.reflection.v2alpha1.AppDescriptor.chain', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codec', full_name='cosmos.base.reflection.v2alpha1.AppDescriptor.codec', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configuration', full_name='cosmos.base.reflection.v2alpha1.AppDescriptor.configuration', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_services', full_name='cosmos.base.reflection.v2alpha1.AppDescriptor.query_services', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx', full_name='cosmos.base.reflection.v2alpha1.AppDescriptor.tx', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=548,
)


_TXDESCRIPTOR = _descriptor.Descriptor(
  name='TxDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.TxDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fullname', full_name='cosmos.base.reflection.v2alpha1.TxDescriptor.fullname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msgs', full_name='cosmos.base.reflection.v2alpha1.TxDescriptor.msgs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=644,
)


_AUTHNDESCRIPTOR = _descriptor.Descriptor(
  name='AuthnDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.AuthnDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sign_modes', full_name='cosmos.base.reflection.v2alpha1.AuthnDescriptor.sign_modes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=646,
  serialized_end=739,
)


_SIGNINGMODEDESCRIPTOR = _descriptor.Descriptor(
  name='SigningModeDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.SigningModeDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='cosmos.base.reflection.v2alpha1.SigningModeDescriptor.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='cosmos.base.reflection.v2alpha1.SigningModeDescriptor.number', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authn_info_provider_method_fullname', full_name='cosmos.base.reflection.v2alpha1.SigningModeDescriptor.authn_info_provider_method_fullname', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=839,
)


_CHAINDESCRIPTOR = _descriptor.Descriptor(
  name='ChainDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.ChainDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='cosmos.base.reflection.v2alpha1.ChainDescriptor.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=841,
  serialized_end=870,
)


_CODECDESCRIPTOR = _descriptor.Descriptor(
  name='CodecDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.CodecDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interfaces', full_name='cosmos.base.reflection.v2alpha1.CodecDescriptor.interfaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=872,
  serialized_end=963,
)


_INTERFACEDESCRIPTOR = _descriptor.Descriptor(
  name='InterfaceDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.InterfaceDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fullname', full_name='cosmos.base.reflection.v2alpha1.InterfaceDescriptor.fullname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interface_accepting_messages', full_name='cosmos.base.reflection.v2alpha1.InterfaceDescriptor.interface_accepting_messages', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interface_implementers', full_name='cosmos.base.reflection.v2alpha1.InterfaceDescriptor.interface_implementers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=966,
  serialized_end=1210,
)


_INTERFACEIMPLEMENTERDESCRIPTOR = _descriptor.Descriptor(
  name='InterfaceImplementerDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.InterfaceImplementerDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fullname', full_name='cosmos.base.reflection.v2alpha1.InterfaceImplementerDescriptor.fullname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_url', full_name='cosmos.base.reflection.v2alpha1.InterfaceImplementerDescriptor.type_url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1212,
  serialized_end=1280,
)


_INTERFACEACCEPTINGMESSAGEDESCRIPTOR = _descriptor.Descriptor(
  name='InterfaceAcceptingMessageDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.InterfaceAcceptingMessageDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fullname', full_name='cosmos.base.reflection.v2alpha1.InterfaceAcceptingMessageDescriptor.fullname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field_descriptor_names', full_name='cosmos.base.reflection.v2alpha1.InterfaceAcceptingMessageDescriptor.field_descriptor_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1282,
  serialized_end=1369,
)


_CONFIGURATIONDESCRIPTOR = _descriptor.Descriptor(
  name='ConfigurationDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.ConfigurationDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bech32_account_address_prefix', full_name='cosmos.base.reflection.v2alpha1.ConfigurationDescriptor.bech32_account_address_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1371,
  serialized_end=1435,
)


_MSGDESCRIPTOR = _descriptor.Descriptor(
  name='MsgDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.MsgDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg_type_url', full_name='cosmos.base.reflection.v2alpha1.MsgDescriptor.msg_type_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1437,
  serialized_end=1474,
)


_GETAUTHNDESCRIPTORREQUEST = _descriptor.Descriptor(
  name='GetAuthnDescriptorRequest',
  full_name='cosmos.base.reflection.v2alpha1.GetAuthnDescriptorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1476,
  serialized_end=1503,
)


_GETAUTHNDESCRIPTORRESPONSE = _descriptor.Descriptor(
  name='GetAuthnDescriptorResponse',
  full_name='cosmos.base.reflection.v2alpha1.GetAuthnDescriptorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='authn', full_name='cosmos.base.reflection.v2alpha1.GetAuthnDescriptorResponse.authn', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1505,
  serialized_end=1598,
)


_GETCHAINDESCRIPTORREQUEST = _descriptor.Descriptor(
  name='GetChainDescriptorRequest',
  full_name='cosmos.base.reflection.v2alpha1.GetChainDescriptorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1600,
  serialized_end=1627,
)


_GETCHAINDESCRIPTORRESPONSE = _descriptor.Descriptor(
  name='GetChainDescriptorResponse',
  full_name='cosmos.base.reflection.v2alpha1.GetChainDescriptorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chain', full_name='cosmos.base.reflection.v2alpha1.GetChainDescriptorResponse.chain', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1629,
  serialized_end=1722,
)


_GETCODECDESCRIPTORREQUEST = _descriptor.Descriptor(
  name='GetCodecDescriptorRequest',
  full_name='cosmos.base.reflection.v2alpha1.GetCodecDescriptorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1724,
  serialized_end=1751,
)


_GETCODECDESCRIPTORRESPONSE = _descriptor.Descriptor(
  name='GetCodecDescriptorResponse',
  full_name='cosmos.base.reflection.v2alpha1.GetCodecDescriptorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='codec', full_name='cosmos.base.reflection.v2alpha1.GetCodecDescriptorResponse.codec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1753,
  serialized_end=1846,
)


_GETCONFIGURATIONDESCRIPTORREQUEST = _descriptor.Descriptor(
  name='GetConfigurationDescriptorRequest',
  full_name='cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1848,
  serialized_end=1883,
)


_GETCONFIGURATIONDESCRIPTORRESPONSE = _descriptor.Descriptor(
  name='GetConfigurationDescriptorResponse',
  full_name='cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1885,
  serialized_end=1995,
)


_GETQUERYSERVICESDESCRIPTORREQUEST = _descriptor.Descriptor(
  name='GetQueryServicesDescriptorRequest',
  full_name='cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1997,
  serialized_end=2032,
)


_GETQUERYSERVICESDESCRIPTORRESPONSE = _descriptor.Descriptor(
  name='GetQueryServicesDescriptorResponse',
  full_name='cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='queries', full_name='cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorResponse.queries', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2034,
  serialized_end=2145,
)


_GETTXDESCRIPTORREQUEST = _descriptor.Descriptor(
  name='GetTxDescriptorRequest',
  full_name='cosmos.base.reflection.v2alpha1.GetTxDescriptorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2147,
  serialized_end=2171,
)


_GETTXDESCRIPTORRESPONSE = _descriptor.Descriptor(
  name='GetTxDescriptorResponse',
  full_name='cosmos.base.reflection.v2alpha1.GetTxDescriptorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx', full_name='cosmos.base.reflection.v2alpha1.GetTxDescriptorResponse.tx', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2173,
  serialized_end=2257,
)


_QUERYSERVICESDESCRIPTOR = _descriptor.Descriptor(
  name='QueryServicesDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.QueryServicesDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query_services', full_name='cosmos.base.reflection.v2alpha1.QueryServicesDescriptor.query_services', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2259,
  serialized_end=2365,
)


_QUERYSERVICEDESCRIPTOR = _descriptor.Descriptor(
  name='QueryServiceDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.QueryServiceDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fullname', full_name='cosmos.base.reflection.v2alpha1.QueryServiceDescriptor.fullname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_module', full_name='cosmos.base.reflection.v2alpha1.QueryServiceDescriptor.is_module', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='methods', full_name='cosmos.base.reflection.v2alpha1.QueryServiceDescriptor.methods', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2368,
  serialized_end=2502,
)


_QUERYMETHODDESCRIPTOR = _descriptor.Descriptor(
  name='QueryMethodDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.QueryMethodDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='cosmos.base.reflection.v2alpha1.QueryMethodDescriptor.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='full_query_path', full_name='cosmos.base.reflection.v2alpha1.QueryMethodDescriptor.full_query_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2504,
  serialized_end=2566,
)

_APPDESCRIPTOR.fields_by_name['authn'].message_type = _AUTHNDESCRIPTOR
_APPDESCRIPTOR.fields_by_name['chain'].message_type = _CHAINDESCRIPTOR
_APPDESCRIPTOR.fields_by_name['codec'].message_type = _CODECDESCRIPTOR
_APPDESCRIPTOR.fields_by_name['configuration'].message_type = _CONFIGURATIONDESCRIPTOR
_APPDESCRIPTOR.fields_by_name['query_services'].message_type = _QUERYSERVICESDESCRIPTOR
_APPDESCRIPTOR.fields_by_name['tx'].message_type = _TXDESCRIPTOR
_TXDESCRIPTOR.fields_by_name['msgs'].message_type = _MSGDESCRIPTOR
_AUTHNDESCRIPTOR.fields_by_name['sign_modes'].message_type = _SIGNINGMODEDESCRIPTOR
_CODECDESCRIPTOR.fields_by_name['interfaces'].message_type = _INTERFACEDESCRIPTOR
_INTERFACEDESCRIPTOR.fields_by_name['interface_accepting_messages'].message_type = _INTERFACEACCEPTINGMESSAGEDESCRIPTOR
_INTERFACEDESCRIPTOR.fields_by_name['interface_implementers'].message_type = _INTERFACEIMPLEMENTERDESCRIPTOR
_GETAUTHNDESCRIPTORRESPONSE.fields_by_name['authn'].message_type = _AUTHNDESCRIPTOR
_GETCHAINDESCRIPTORRESPONSE.fields_by_name['chain'].message_type = _CHAINDESCRIPTOR
_GETCODECDESCRIPTORRESPONSE.fields_by_name['codec'].message_type = _CODECDESCRIPTOR
_GETCONFIGURATIONDESCRIPTORRESPONSE.fields_by_name['config'].message_type = _CONFIGURATIONDESCRIPTOR
_GETQUERYSERVICESDESCRIPTORRESPONSE.fields_by_name['queries'].message_type = _QUERYSERVICESDESCRIPTOR
_GETTXDESCRIPTORRESPONSE.fields_by_name['tx'].message_type = _TXDESCRIPTOR
_QUERYSERVICESDESCRIPTOR.fields_by_name['query_services'].message_type = _QUERYSERVICEDESCRIPTOR
_QUERYSERVICEDESCRIPTOR.fields_by_name['methods'].message_type = _QUERYMETHODDESCRIPTOR
DESCRIPTOR.message_types_by_name['AppDescriptor'] = _APPDESCRIPTOR
DESCRIPTOR.message_types_by_name['TxDescriptor'] = _TXDESCRIPTOR
DESCRIPTOR.message_types_by_name['AuthnDescriptor'] = _AUTHNDESCRIPTOR
DESCRIPTOR.message_types_by_name['SigningModeDescriptor'] = _SIGNINGMODEDESCRIPTOR
DESCRIPTOR.message_types_by_name['ChainDescriptor'] = _CHAINDESCRIPTOR
DESCRIPTOR.message_types_by_name['CodecDescriptor'] = _CODECDESCRIPTOR
DESCRIPTOR.message_types_by_name['InterfaceDescriptor'] = _INTERFACEDESCRIPTOR
DESCRIPTOR.message_types_by_name['InterfaceImplementerDescriptor'] = _INTERFACEIMPLEMENTERDESCRIPTOR
DESCRIPTOR.message_types_by_name['InterfaceAcceptingMessageDescriptor'] = _INTERFACEACCEPTINGMESSAGEDESCRIPTOR
DESCRIPTOR.message_types_by_name['ConfigurationDescriptor'] = _CONFIGURATIONDESCRIPTOR
DESCRIPTOR.message_types_by_name['MsgDescriptor'] = _MSGDESCRIPTOR
DESCRIPTOR.message_types_by_name['GetAuthnDescriptorRequest'] = _GETAUTHNDESCRIPTORREQUEST
DESCRIPTOR.message_types_by_name['GetAuthnDescriptorResponse'] = _GETAUTHNDESCRIPTORRESPONSE
DESCRIPTOR.message_types_by_name['GetChainDescriptorRequest'] = _GETCHAINDESCRIPTORREQUEST
DESCRIPTOR.message_types_by_name['GetChainDescriptorResponse'] = _GETCHAINDESCRIPTORRESPONSE
DESCRIPTOR.message_types_by_name['GetCodecDescriptorRequest'] = _GETCODECDESCRIPTORREQUEST
DESCRIPTOR.message_types_by_name['GetCodecDescriptorResponse'] = _GETCODECDESCRIPTORRESPONSE
DESCRIPTOR.message_types_by_name['GetConfigurationDescriptorRequest'] = _GETCONFIGURATIONDESCRIPTORREQUEST
DESCRIPTOR.message_types_by_name['GetConfigurationDescriptorResponse'] = _GETCONFIGURATIONDESCRIPTORRESPONSE
DESCRIPTOR.message_types_by_name['GetQueryServicesDescriptorRequest'] = _GETQUERYSERVICESDESCRIPTORREQUEST
DESCRIPTOR.message_types_by_name['GetQueryServicesDescriptorResponse'] = _GETQUERYSERVICESDESCRIPTORRESPONSE
DESCRIPTOR.message_types_by_name['GetTxDescriptorRequest'] = _GETTXDESCRIPTORREQUEST
DESCRIPTOR.message_types_by_name['GetTxDescriptorResponse'] = _GETTXDESCRIPTORRESPONSE
DESCRIPTOR.message_types_by_name['QueryServicesDescriptor'] = _QUERYSERVICESDESCRIPTOR
DESCRIPTOR.message_types_by_name['QueryServiceDescriptor'] = _QUERYSERVICEDESCRIPTOR
DESCRIPTOR.message_types_by_name['QueryMethodDescriptor'] = _QUERYMETHODDESCRIPTOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AppDescriptor = _reflection.GeneratedProtocolMessageType('AppDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _APPDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.AppDescriptor)
  })
_sym_db.RegisterMessage(AppDescriptor)

TxDescriptor = _reflection.GeneratedProtocolMessageType('TxDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _TXDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.TxDescriptor)
  })
_sym_db.RegisterMessage(TxDescriptor)

AuthnDescriptor = _reflection.GeneratedProtocolMessageType('AuthnDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _AUTHNDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.AuthnDescriptor)
  })
_sym_db.RegisterMessage(AuthnDescriptor)

SigningModeDescriptor = _reflection.GeneratedProtocolMessageType('SigningModeDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _SIGNINGMODEDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.SigningModeDescriptor)
  })
_sym_db.RegisterMessage(SigningModeDescriptor)

ChainDescriptor = _reflection.GeneratedProtocolMessageType('ChainDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _CHAINDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.ChainDescriptor)
  })
_sym_db.RegisterMessage(ChainDescriptor)

CodecDescriptor = _reflection.GeneratedProtocolMessageType('CodecDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _CODECDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.CodecDescriptor)
  })
_sym_db.RegisterMessage(CodecDescriptor)

InterfaceDescriptor = _reflection.GeneratedProtocolMessageType('InterfaceDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _INTERFACEDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.InterfaceDescriptor)
  })
_sym_db.RegisterMessage(InterfaceDescriptor)

InterfaceImplementerDescriptor = _reflection.GeneratedProtocolMessageType('InterfaceImplementerDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _INTERFACEIMPLEMENTERDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.InterfaceImplementerDescriptor)
  })
_sym_db.RegisterMessage(InterfaceImplementerDescriptor)

InterfaceAcceptingMessageDescriptor = _reflection.GeneratedProtocolMessageType('InterfaceAcceptingMessageDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _INTERFACEACCEPTINGMESSAGEDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.InterfaceAcceptingMessageDescriptor)
  })
_sym_db.RegisterMessage(InterfaceAcceptingMessageDescriptor)

ConfigurationDescriptor = _reflection.GeneratedProtocolMessageType('ConfigurationDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGURATIONDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.ConfigurationDescriptor)
  })
_sym_db.RegisterMessage(ConfigurationDescriptor)

MsgDescriptor = _reflection.GeneratedProtocolMessageType('MsgDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _MSGDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.MsgDescriptor)
  })
_sym_db.RegisterMessage(MsgDescriptor)

GetAuthnDescriptorRequest = _reflection.GeneratedProtocolMessageType('GetAuthnDescriptorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAUTHNDESCRIPTORREQUEST,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetAuthnDescriptorRequest)
  })
_sym_db.RegisterMessage(GetAuthnDescriptorRequest)

GetAuthnDescriptorResponse = _reflection.GeneratedProtocolMessageType('GetAuthnDescriptorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAUTHNDESCRIPTORRESPONSE,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetAuthnDescriptorResponse)
  })
_sym_db.RegisterMessage(GetAuthnDescriptorResponse)

GetChainDescriptorRequest = _reflection.GeneratedProtocolMessageType('GetChainDescriptorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCHAINDESCRIPTORREQUEST,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetChainDescriptorRequest)
  })
_sym_db.RegisterMessage(GetChainDescriptorRequest)

GetChainDescriptorResponse = _reflection.GeneratedProtocolMessageType('GetChainDescriptorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCHAINDESCRIPTORRESPONSE,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetChainDescriptorResponse)
  })
_sym_db.RegisterMessage(GetChainDescriptorResponse)

GetCodecDescriptorRequest = _reflection.GeneratedProtocolMessageType('GetCodecDescriptorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCODECDESCRIPTORREQUEST,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetCodecDescriptorRequest)
  })
_sym_db.RegisterMessage(GetCodecDescriptorRequest)

GetCodecDescriptorResponse = _reflection.GeneratedProtocolMessageType('GetCodecDescriptorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCODECDESCRIPTORRESPONSE,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetCodecDescriptorResponse)
  })
_sym_db.RegisterMessage(GetCodecDescriptorResponse)

GetConfigurationDescriptorRequest = _reflection.GeneratedProtocolMessageType('GetConfigurationDescriptorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGURATIONDESCRIPTORREQUEST,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorRequest)
  })
_sym_db.RegisterMessage(GetConfigurationDescriptorRequest)

GetConfigurationDescriptorResponse = _reflection.GeneratedProtocolMessageType('GetConfigurationDescriptorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGURATIONDESCRIPTORRESPONSE,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorResponse)
  })
_sym_db.RegisterMessage(GetConfigurationDescriptorResponse)

GetQueryServicesDescriptorRequest = _reflection.GeneratedProtocolMessageType('GetQueryServicesDescriptorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYSERVICESDESCRIPTORREQUEST,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorRequest)
  })
_sym_db.RegisterMessage(GetQueryServicesDescriptorRequest)

GetQueryServicesDescriptorResponse = _reflection.GeneratedProtocolMessageType('GetQueryServicesDescriptorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYSERVICESDESCRIPTORRESPONSE,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorResponse)
  })
_sym_db.RegisterMessage(GetQueryServicesDescriptorResponse)

GetTxDescriptorRequest = _reflection.GeneratedProtocolMessageType('GetTxDescriptorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTXDESCRIPTORREQUEST,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetTxDescriptorRequest)
  })
_sym_db.RegisterMessage(GetTxDescriptorRequest)

GetTxDescriptorResponse = _reflection.GeneratedProtocolMessageType('GetTxDescriptorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTXDESCRIPTORRESPONSE,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetTxDescriptorResponse)
  })
_sym_db.RegisterMessage(GetTxDescriptorResponse)

QueryServicesDescriptor = _reflection.GeneratedProtocolMessageType('QueryServicesDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSERVICESDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.QueryServicesDescriptor)
  })
_sym_db.RegisterMessage(QueryServicesDescriptor)

QueryServiceDescriptor = _reflection.GeneratedProtocolMessageType('QueryServiceDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSERVICEDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.QueryServiceDescriptor)
  })
_sym_db.RegisterMessage(QueryServiceDescriptor)

QueryMethodDescriptor = _reflection.GeneratedProtocolMessageType('QueryMethodDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMETHODDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.QueryMethodDescriptor)
  })
_sym_db.RegisterMessage(QueryMethodDescriptor)


DESCRIPTOR._options = None

_REFLECTIONSERVICE = _descriptor.ServiceDescriptor(
  name='ReflectionService',
  full_name='cosmos.base.reflection.v2alpha1.ReflectionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2569,
  serialized_end=3888,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAuthnDescriptor',
    full_name='cosmos.base.reflection.v2alpha1.ReflectionService.GetAuthnDescriptor',
    index=0,
    containing_service=None,
    input_type=_GETAUTHNDESCRIPTORREQUEST,
    output_type=_GETAUTHNDESCRIPTORRESPONSE,
    serialized_options=b'\202\323\344\223\0026\0224/cosmos/base/reflection/v1beta1/app_descriptor/authn',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetChainDescriptor',
    full_name='cosmos.base.reflection.v2alpha1.ReflectionService.GetChainDescriptor',
    index=1,
    containing_service=None,
    input_type=_GETCHAINDESCRIPTORREQUEST,
    output_type=_GETCHAINDESCRIPTORRESPONSE,
    serialized_options=b'\202\323\344\223\0026\0224/cosmos/base/reflection/v1beta1/app_descriptor/chain',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCodecDescriptor',
    full_name='cosmos.base.reflection.v2alpha1.ReflectionService.GetCodecDescriptor',
    index=2,
    containing_service=None,
    input_type=_GETCODECDESCRIPTORREQUEST,
    output_type=_GETCODECDESCRIPTORRESPONSE,
    serialized_options=b'\202\323\344\223\0026\0224/cosmos/base/reflection/v1beta1/app_descriptor/codec',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetConfigurationDescriptor',
    full_name='cosmos.base.reflection.v2alpha1.ReflectionService.GetConfigurationDescriptor',
    index=3,
    containing_service=None,
    input_type=_GETCONFIGURATIONDESCRIPTORREQUEST,
    output_type=_GETCONFIGURATIONDESCRIPTORRESPONSE,
    serialized_options=b'\202\323\344\223\002>\022</cosmos/base/reflection/v1beta1/app_descriptor/configuration',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetQueryServicesDescriptor',
    full_name='cosmos.base.reflection.v2alpha1.ReflectionService.GetQueryServicesDescriptor',
    index=4,
    containing_service=None,
    input_type=_GETQUERYSERVICESDESCRIPTORREQUEST,
    output_type=_GETQUERYSERVICESDESCRIPTORRESPONSE,
    serialized_options=b'\202\323\344\223\002?\022=/cosmos/base/reflection/v1beta1/app_descriptor/query_services',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTxDescriptor',
    full_name='cosmos.base.reflection.v2alpha1.ReflectionService.GetTxDescriptor',
    index=5,
    containing_service=None,
    input_type=_GETTXDESCRIPTORREQUEST,
    output_type=_GETTXDESCRIPTORRESPONSE,
    serialized_options=b'\202\323\344\223\002>\022</cosmos/base/reflection/v1beta1/app_descriptor/tx_descriptor',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_REFLECTIONSERVICE)

DESCRIPTOR.services_by_name['ReflectionService'] = _REFLECTIONSERVICE

# @@protoc_insertion_point(module_scope)
